@@ -6,9 +6,7 @@ import numpy as np
 
 
 def GetBestConformerRMS(
-    mol: rdChem.Mol,
-    heavyAtomsOnly: bool = False,
-    confIds: Optional[List[int]] = None
+    mol: rdChem.Mol, heavyAtomsOnly: bool = False, confIds: Optional[List[int]] = None
 ) -> np.ndarray:
     """Get square array of conformer-to-conformer symmetric RMS
 
@@ -37,7 +35,15 @@ def GetBestConformerRMS(
     n_conformers = len(confIds)
 
     if heavyAtomsOnly:
-        mol = rdChem.RemoveAllHs(mol)
+        mol = rdChem.RemoveAllHs(mol, sanitize=False)
+        rdChem.SanitizeMol(
+            mol,
+            rdChem.SANITIZE_ALL
+            ^ rdChem.SANITIZE_SETAROMATICITY
+            ^ rdChem.SANITIZE_SETCONJUGATION
+            ^ rdChem.SANITIZE_SETHYBRIDIZATION
+            ^ rdChem.SANITIZE_ADJUSTHS,
+        )
 
     rms = np.zeros((n_conformers, n_conformers))
     for i, j in itertools.combinations(np.arange(n_conformers), 2):
